<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 08/31/2003 *
 * ===================                          Last change: 07/02/2004 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : admin.php                                        *
 * -------------------------------------------------------------------- *
 * Short description : Administration module                            *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Administrationsmodul                             *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2011 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

// Load include file
loadIncludeOnce('inc/modules/admin/admin-inc.php');

// Fix "deleted" cookies in PHP4 (PHP5 does remove them, PHP4 sets them to deleted!)
fixDeletedCookies(array('admin_id', 'admin_md5', 'admin_last'));

// Init return value
$ret = 'init';

// Is no admin registered?
if (!isAdminRegistered()) {
	// Admin is not registered so we have to inform the user
	if ((isFormSent()) && ((!isPostRequestElementSet('admin_login')) || (!isPostRequestElementSet('admin_pass1')) || (strlen(postRequestElement('admin_pass1')) < getConfig('minium_admin_pass_length')) || (!isPostRequestElementSet('admin_pass2')) || (strlen(postRequestElement('admin_pass2')) < getConfig('minium_admin_pass_length')) || (postRequestElement('admin_pass1') != postRequestElement('admin_pass2')))) {
		setPostRequestElement('ok', '***');
	} // END - if

	// Clear error message
	$errorMessage = '';

	if ((isFormSent()) && (postRequestElement('ok') != '***')) {
		// Hash the password with the old function because we are here in install mode
		$hashedPass = md5(postRequestElement('admin_pass1'));

		// Kill maybe existing session variables
		destroyAdminSession(false);

		// Do registration
		$ret = addAdminAccount(postRequestElement('admin_login'), $hashedPass, getWebmaster());

		// Check if registration wents fine
		switch ($ret) {
			case 'done':
				// Change ADMIN_REGISTERED entry
				$done = changeDataInLocalConfigurationFile('ADMIN-SETUP', "setConfigEntry('ADMIN_REGISTERED', '", "');", 'Y', 0);

				// Was it successfull?
				if ($done === true) {
					// Registering is done
					redirectToUrl('modules.php?module=admin&amp;register=done');
				} else {
					// Registration incomplete
					$errorMessage = '{--ADMIN_CANNOT_COMPLETE--}';

					// Set this to have our error message displayed
					setPostRequestElement('ok', '***');
				}
				break;

			case 'failed': // Registration has failed
				$errorMessage = '{--ADMIN_REGISTER_FAILED--}';

				// Set this to have our error message displayed
				setPostRequestElement('ok', '***');
				break;

			case 'already': // Admin does already exists!
				$errorMessage = '{--ADMIN_LOGIN_ALREADY_REG--}';

				// Set this to have our error message displayed
				setPostRequestElement('ok', '***');
				break;

			default:
				// Any other kind will be logged
				$errorMessage = sprintf("Unknown return code %s from ifAdminLoginDataIsValid().", $ret);
				logDebugMessage(__FILE__, __LINE__, $errorMessage);

				// Set this to have our error message displayed
				setPostRequestElement('ok', '***');
				break;
		} // END - switch
	} // END - if

	// Whas that action okay?
	if ($ret != 'done') {
		// Init login name
		$content['admin_login'] = '';
		if (isPostRequestElementSet('admin_login')) {
			$content['admin_login'] = postRequestElement('admin_login');
		} // END - if

		// Init array elements
		$content['login_message'] = '';
		$content['pass1_message'] = '';
		$content['pass2_message'] = '';
		$content['error_message'] = '';

		// Yet-another notice-fix
		if ((isFormSent()) && (postRequestElement('ok') == '***')) {
			// Init variables
			$loginMessage = '';
			$pass1Message = '';
			$pass2Message = '';

			// No login entered?
			if (empty($content['admin_login'])) {
				$loginMessage = '{--ADMIN_NO_LOGIN--}';
			} // END - if

			// An error comes back from registration?
			if ((!empty($ret)) && ($ret != 'init')) {
				$loginMessage = $errorMessage;
			} // END - if

			// No password 1 entered or to short?
			if (!isPostRequestElementSet('admin_pass1')) {
				$pass1Message = '{--ADMIN_NO_PASSWORD1--}';
			} elseif (strlen(postRequestElement('admin_pass1')) < getConfig('minium_admin_pass_length')) {
				$pass1Message = '{--ADMIN_SHORT_PASSWORD1--}';
			}

			// No password 2 entered or to short?
			if (!isPostRequestElementSet('admin_pass2')) {
				$pass2Message = '{--ADMIN_NO_PASSWORD2--}';
			} elseif (strlen(postRequestElement('admin_pass2')) < getConfig('minium_admin_pass_length')) {
				$pass2Message = '{--ADMIN_SHORT_PASSWORD2--}';
			}

			// Both didn't match?
			if (postRequestElement('admin_pass1') != postRequestElement('admin_pass2')) {
				// No match
				if (empty($pass1Message)) $pass1Message = '{--ADMIN_PASSWORD1_MISMATCH--}';
				if (empty($pass2Message)) $pass2Message = '{--ADMIN_PASSWORD2_MISMATCH--}';
			} // END - if

			// Output error messages
			$content['login_message'] = loadTemplate('admin_login_msg', true, $loginMessage);
			$content['pass1_message'] = loadTemplate('admin_login_msg', true, $pass1Message);
			$content['pass2_message'] = loadTemplate('admin_login_msg', true, $pass2Message);
			$content['error_message'] = loadTemplate('admin_login_msg', true, $errorMessage);
		} // END - if

		// Output message in seperate template
		displayMessage('{--ADMIN_ACCOUNT_NOT_REGISTERED_YET--}');

		// Load register template
		loadTemplate('admin_reg_form', false, $content);
	} // END - if
} elseif (isGetRequestElementSet('reset_pass')) {
	// Is the form submitted?
	if ((isPostRequestElementSet('send_link')) && (isPostRequestElementSet('email'))) {
		// Output result
		displayMessage(sendAdminPasswordResetLink(postRequestElement('email')));
	} elseif (isGetRequestElementSet('hash')) {
		// Output form for hash validation
		loadTemplate('admin_validate_reset_hash_form', false, getRequestElement('hash'));
	} elseif ((isPostRequestElementSet('validate_hash')) && (isPostRequestElementSet('admin_login')) && (isPostRequestElementSet('hash'))) {
		// Validate the login data and hash
		$valid = adminResetValidateHashLogin(postRequestElement('hash'), postRequestElement('admin_login'));

		// Valid?
		if ($valid === true) {
			// Prepare content first
			$content = array(
				'hash'        => postRequestElement('hash'),
				'admin_login' => postRequestElement('admin_login')
			);

			// Validation okay so display form for final password change
			loadTemplate('admin_reset_password_form', false, $content);
		} else {
			// Cannot validate the login data and hash
			displayMessage('{--ADMIN_VALIDATION_RESET_LOGIN_HASH_FAILED--}');
		}
	} elseif ((isPostRequestElementSet('reset_pass')) && (isPostRequestElementSet('hash')) && (isPostRequestElementSet('admin_login')) && (isPostRequestElementSet('admin_pass1')) && (postRequestElement('admin_pass1') == postRequestElement('admin_pass2'))) {
		// Okay, we shall the admin password here. So first revalidate the hash
		if (adminResetValidateHashLogin(postRequestElement('hash'), postRequestElement('admin_login'))) {
			// Output result
			loadTemplate('admin_reset_password_done', false, doResetAdminPassword(postRequestElement('admin_login'), postRequestElement('admin_pass1')));
		} else {
			// Validation failed
			displayMessage('{--ADMIN_VALIDATION_RESET_LOGIN_HASH_FAILED2--}');
		}
	} else {
		// Output reset password form
		loadTemplate('admin_reset_password_send_link');
	}
} elseif ((!isSessionVariableSet('admin_id')) || (!isSessionVariableSet('admin_md5')) || (!isSessionVariableSet('admin_last'))) {
	// At leat one administrator account was created
	if ((isSessionVariableSet('admin_id')) && (isSessionVariableSet('admin_md5')) && (isSessionVariableSet('admin_last'))) {
		// Timeout for last login, we have to logout first!
		redirectToUrl('modules.php?module=admin&amp;logout=1');
	} // END - if

	if (isGetRequestElementSet('register')) {
		// Registration of first admin is done
		if (getRequestElement('register') == 'done') {
			// Regisration done!
			displayMessage('{--ADMIN_REGISTER_DONE--}');
		} // END - if
	} // END - if

	// Check if the admin has submitted data or not
	if ((isFormSent()) && ((!isPostRequestElementSet('admin_login')) || (!isPostRequestElementSet('admin_password')) || (strlen(postRequestElement('admin_password')) < getConfig('minium_admin_pass_length')))) {
		setPostRequestElement('ok', '***');
	} // END - if

	if ((isFormSent()) && (postRequestElement('ok') != '***')) {
		// All required data was entered so we check his account
		$ret = ifAdminLoginDataIsValid(postRequestElement('admin_login'), postRequestElement('admin_password'));

		// Which status do we have?
		switch ($ret) {
			case 'done': // Admin and password are okay, so we log in now
				// Load URL
				redirectToUrl('modules.php?' . addAllGetRequestParameters());
				break;

			case '404': // Administrator login not found
				setPostRequestElement('ok', $ret);
				$ret = '{%message,ADMIN_ACCOUNT_404=' . postRequestElement('admin_login') . '%}';
				destroyAdminSession();
				break;

			case 'password': // Wrong password
				setPostRequestElement('ok', $ret);
				$ret = '{--WRONG_PASS--} [<a href="{%url=modules.php?module=admin&amp;reset_pass=1%}">{--ADMIN_RESET_PASS--}</a>]';
				destroyAdminSession();
				break;

			default: // Others will be logged
				logDebugMessage(__FILE__, __LINE__, sprintf("Unknown return code %s from ifAdminLoginDataIsValid()", $ret));
				break;
		} // END - switch
	} // END - if

	// Error detected?
	if ($ret != 'done') {
		$content['admin_login'] = '';
		if (isPostRequestElementSet('admin_login')) {
			$content['admin_login'] = postRequestElement('admin_login');
		} // END - if

		// Init array elements
		$content['login_message'] = '';
		$content['pass_message']  = '';

		if (isFormSent()) {
			// Set messages to zero
			$loginMessage = '';
			$passwdMessage = '';

			// Check for login
			if (!isPostRequestElementSet('admin_login')) {
				// No login entered?
				$loginMessage = '{--ADMIN_NO_LOGIN--}';
			} elseif ((!empty($ret)) && (postRequestElement('ok') == '404')) {
				// An error comes back from login?
				$loginMessage = $ret;
			}

			// Check for password
			if (!isPostRequestElementSet('admin_password')) {
				// No password entered?
				$passwdMessage = '{--ADMIN_NO_PASS--}';
			} elseif (strlen(postRequestElement('admin_password')) < getConfig('minium_admin_pass_length')) {
				// Or password too short?
				$passwdMessage = '{--ADMIN_SHORT_PASS--}';
			} elseif ((!empty($ret)) && (postRequestElement('ok') == 'password')) {
				// An error comes back from login?
				$passwdMessage = $ret;
			}

			// Load message templates if the messages have been set
			if (!empty($loginMessage)) {
				$content['login_message'] = loadTemplate('admin_login_msg', true, $loginMessage);
			} // END - if
			if (!empty($passwdMessage)) {
				$content['pass_message']  = loadTemplate('admin_login_msg', true, $passwdMessage);
			} // END - if
		} // END - if

		// Add all parameter
		$content['all_parameter'] = addAllGetRequestParameters();

		// Load login form template
		loadTemplate('admin_login_form', false, $content);
	} // END - if
} elseif (isGetRequestElementSet('logout')) {
	// Only try to remove cookies
	if (destroyAdminSession()) {
		// Load logout template
		if (isGetRequestElementSet('register')) {
			// Secure input
			$register = getRequestElement('register');

			// Special logout redirect for installation of given extension
			loadTemplate(sprintf("admin_logout_%s_install", $register));
		} elseif (isGetRequestElementSet('remove')) {
			// Secure input
			$remove = getRequestElement('remove');

			// Special logout redirect for removal of given extension
			loadTemplate(sprintf("admin_logout_%s_remove", $remove));
		} else {
			// Logged out normally
			loadTemplate('admin_logout');
		}
	} else {
		// Something went wrong here...
		loadTemplate('admin_settings_unsaved', false, '{--ADMIN_LOGOUT_FAILED--}');

		// Add fatal message
		addFatalMessage(__FILE__, __LINE__, '{--CANNOT_UNREG_SESS--}');
	}
} else {
	// Maybe an Admin want's to login?
	$ret = ifAdminCookiesAreValid(getCurrentAdminId(), getAdminMd5());

	// Check status
	switch ($ret) {
		case 'done':
			// Check for access control line of current menu entry
			runFilterChain('check_admin_acl');

			// Check for version and switch between old menu system and new intelligent menu system
			if ((adminGetMenuMode() == 'NEW') && (isIncludeReadable('inc/modules/admin/lasys-inc.php'))) {
				// Default area is the entrance, of course
				$area = 'entrance';

				// Check for similar URL variable
				if (isGetRequestElementSet('area')) $area = getRequestElement('area');

				// Load logical-area menu-system file
				loadIncludeOnce('inc/modules/admin/lasys-inc.php');

				// Create new-style menu system will logical areas
				doAdminLogicalArea($area, $action, getWhat());
			} else {
				// This little call constructs the whole default old and lacky menu system
				// on left side. It also renders the content on right side
				doAdminAction();
			}
			break;

		case '404': // Administrator login not found
			setPostRequestElement('ok', $ret);
			displayMessage('{%message,ADMIN_ACCOUNT_404=' . getCurrentAdminId() . '%}');
			destroyAdminSession();
			break;

		case 'password': // Wrong password
			setPostRequestElement('ok', $ret);
			displayMessage('{--WRONG_PASS--}');
			destroyAdminSession();
			break;

		default: // Others will be logged
			logDebugMessage(__FILE__, __LINE__, sprintf("Unknown return code %s from ifAdminCookiesAreValid()", $ret));
			break;
	} // END - switch
}

// [EOF]
?>
